# flaked
flaked add mako file's python code checker base on flake8

## Quick Start
```shell
> pip install flaked
> flaked <some_mako_file>
```

You can use `flaked` just like flake8, because flaked is a wrapper of flake8, but for mako file.
